Learn R Programming

bursa (version 0.1.0)

search_data_by_keyword: search_data_by_keyword

Description

Given a key word, this function returns the dataset names including key word

Usage

search_data_by_keyword(key_word)

Value

A character vector object that shows the name of the datasets including key word

Arguments

key_word

A data set name which is a character object

Examples

Run this code
# \donttest{
search_data_by_keyword("covid")
# }

Run the code above in your browser using DataLab