powered by
Given a key word, this function returns the dataset names including key word
search_data_by_keyword(key_word)
A character vector object that shows the name of the datasets including key word
A data set name which is a character object
# \donttest{ search_data_by_keyword("covid") # }
Run the code above in your browser using DataLab